@@ -43,6 +43,114 @@
 
 "use strict";
 
+import * as ast from "./ast.js";
+import {
+    AST_Accessor,
+    AST_Array,
+    AST_Arrow,
+    AST_Assign,
+    AST_Atom,
+    AST_Await,
+    AST_BigInt,
+    AST_Binary,
+    AST_Block,
+    AST_BlockStatement,
+    AST_Boolean,
+    AST_Break,
+    AST_Call,
+    AST_Case,
+    AST_Catch,
+    AST_Class,
+    AST_ClassExpression,
+    AST_ConciseMethod,
+    AST_Conditional,
+    AST_Const,
+    AST_Constant,
+    AST_Continue,
+    AST_Debugger,
+    AST_Default,
+    AST_DefaultAssign,
+    AST_DefClass,
+    AST_Definitions,
+    AST_Defun,
+    AST_Destructuring,
+    AST_Directive,
+    AST_Do,
+    AST_Dot,
+    AST_EmptyStatement,
+    AST_Expansion,
+    AST_Export,
+    AST_False,
+    AST_Finally,
+    AST_For,
+    AST_ForIn,
+    AST_ForOf,
+    AST_Function,
+    AST_Hole,
+    AST_If,
+    AST_Import,
+    AST_Label,
+    AST_LabeledStatement,
+    AST_LabelRef,
+    AST_Lambda,
+    AST_Let,
+    AST_NameMapping,
+    AST_New,
+    AST_NewTarget,
+    AST_Node,
+    AST_Null,
+    AST_Number,
+    AST_Object,
+    AST_ObjectGetter,
+    AST_ObjectKeyVal,
+    AST_ObjectProperty,
+    AST_ObjectSetter,
+    AST_PrefixedTemplateString,
+    AST_PropAccess,
+    AST_RegExp,
+    AST_Return,
+    AST_Sequence,
+    AST_SimpleStatement,
+    AST_Statement,
+    AST_String,
+    AST_Sub,
+    AST_Super,
+    AST_Switch,
+    AST_SwitchBranch,
+    AST_Symbol,
+    AST_SymbolCatch,
+    AST_SymbolClass,
+    AST_SymbolConst,
+    AST_SymbolDefClass,
+    AST_SymbolDefun,
+    AST_SymbolExport,
+    AST_SymbolExportForeign,
+    AST_SymbolFunarg,
+    AST_SymbolImport,
+    AST_SymbolImportForeign,
+    AST_SymbolLambda,
+    AST_SymbolLet,
+    AST_SymbolMethod,
+    AST_SymbolRef,
+    AST_SymbolVar,
+    AST_TemplateSegment,
+    AST_TemplateString,
+    AST_This,
+    AST_Throw,
+    AST_Token,
+    AST_Toplevel,
+    AST_True,
+    AST_Try,
+    AST_Unary,
+    AST_UnaryPostfix,
+    AST_UnaryPrefix,
+    AST_Var,
+    AST_VarDef,
+    AST_While,
+    AST_With,
+    AST_Yield,
+} from "./ast.js";
+
 (function() {
 
     var normalize_directives = function(body) {
@@ -93,7 +201,16 @@
             });
         },
         AssignmentPattern: function(M) {
-            return new AST_Binary({
+            var Type = AST_Binary;
+            if(FROM_MOZ_STACK.length > 2) {
+                var p = FROM_MOZ_STACK[FROM_MOZ_STACK.length - 2];
+                if(p.type === "FunctionDeclaration"
+                   || p.type === "FunctionExpression"
+                   || p.type === "ArrowFunctionExpression") {
+                    Type = AST_DefaultAssign;
+                }
+            }
+            return new Type({
                 start: my_start_token(M),
                 end: my_end_token(M),
                 left: from_moz(M.left),
@@ -309,7 +426,7 @@
                 definitions : M.declarations.map(from_moz)
             });
         },
-        
+
         ImportDeclaration: function(M) {
             var imported_name = null;
             var imported_names = null;
@@ -424,7 +541,7 @@
                         : p.type == "ExportSpecifier" ? (p.local === M ? AST_SymbolExport : AST_SymbolExportForeign)
                         : p.type == "FunctionExpression" ? (p.id === M ? AST_SymbolLambda : AST_SymbolFunarg)
                         : p.type == "FunctionDeclaration" ? (p.id === M ? AST_SymbolDefun : AST_SymbolFunarg)
-                        : p.type == "ArrowFunctionExpression" ? (p.params.indexOf(M) !== -1) ? AST_SymbolFunarg : AST_SymbolRef
+                        : p.type == "ArrowFunctionExpression" ? (p.params.includes(M)) ? AST_SymbolFunarg : AST_SymbolRef
                         : p.type == "ClassExpression" ? (p.id === M ? AST_SymbolClass : AST_SymbolRef)
                         : p.type == "Property" ? (p.key === M && p.computed || p.value === M ? AST_SymbolRef : AST_SymbolMethod)
                         : p.type == "ClassDeclaration" ? (p.id === M ? AST_SymbolDefClass : AST_SymbolRef)
@@ -436,6 +553,13 @@
                             end   : my_end_token(M),
                             name  : M.name
                         });
+        },
+        BigIntLiteral(M) {
+            return new AST_BigInt({
+                start : my_start_token(M),
+                end   : my_end_token(M),
+                value : M.value
+            });
         }
     };
 
@@ -905,6 +1029,11 @@
         };
     });
 
+    def_to_moz(AST_BigInt, M => ({
+        type: "BigIntLiteral",
+        value: M.value
+    }));
+
     AST_Boolean.DEFMETHOD("to_mozilla_ast", AST_Constant.prototype.to_mozilla_ast);
     AST_Null.DEFMETHOD("to_mozilla_ast", AST_Constant.prototype.to_mozilla_ast);
     AST_Hole.DEFMETHOD("to_mozilla_ast", function To_Moz_ArrayHole() { return null; });
@@ -961,7 +1090,7 @@
             "type: " + JSON.stringify(moztype);
 
         if (propmap) propmap.split(/\s*,\s*/).forEach(function(prop) {
-            var m = /([a-z0-9$_]+)(=|@|>|%)([a-z0-9$_]+)/i.exec(prop);
+            var m = /([a-z0-9$_]+)([=@>%])([a-z0-9$_]+)/i.exec(prop);
             if (!m) throw new Error("Can't understand property map: " + prop);
             var moz = m[1], how = m[2], my = m[3];
             moz_to_me += ",\n" + my + ": ";
@@ -996,7 +1125,7 @@
         //console.log(moz_to_me);
 
         moz_to_me = new Function("U2", "my_start_token", "my_end_token", "from_moz", "return(" + moz_to_me + ")")(
-            exports, my_start_token, my_end_token, from_moz
+            ast, my_start_token, my_end_token, from_moz
         );
         me_to_moz = new Function("to_moz", "to_moz_block", "to_moz_scope", "return(" + me_to_moz + ")")(
             to_moz, to_moz_block, to_moz_scope
