@@ -1285,14 +1285,14 @@ issue_2207_1: {
         console.log(Math.max(3, 6, 2, 7, 3, 4));
         console.log(Math.cos(1.2345));
         console.log(Math.cos(1.2345) - Math.sin(4.321));
-        console.log(Math.pow(Math.PI, Math.E - Math.LN10));
+        console.log(Math.pow(Math.PI, Math.E - Math.LN10).toFixed(15));
     }
     expect: {
         console.log("A");
         console.log(7);
         console.log(Math.cos(1.2345));
         console.log(1.2543732512566947);
-        console.log(1.6093984514472044);
+        console.log("1.609398451447204");
     }
     expect_stdout: true
 }
@@ -1733,14 +1733,18 @@ issue_2968: {
     expect_stdout: "PASS"
 }
 
-issue_192: {
+global_hasOwnProperty: {
     options = {
         unsafe: true
     }
     input: {
         hasOwnProperty.call(a, b)
+        hasOwnProperty.call(a.b, b)
+        hasOwnProperty.call(a['b'], b)
     }
     expect: {
         hasOwnProperty.call(a, b)
+        hasOwnProperty.call(a.b, b)
+        hasOwnProperty.call(a['b'], b)
     }
 }
