@@ -181,37 +181,36 @@ hoist_funs: {
         hoist_funs: true,
     }
     input: {
-        console.log(1, typeof f, typeof g);
-        if (console.log(2, typeof f, typeof g))
-            console.log(3, typeof f, typeof g);
+        console.log(typeof f, typeof g, 1);
+        if (console.log(typeof f, typeof g, 2))
+            console.log(typeof f, typeof g, 3);
         else {
-            console.log(4, typeof f, typeof g);
+            console.log(typeof f, typeof g, 4);
             function f() {}
-            console.log(5, typeof f, typeof g);
+            console.log(typeof f, typeof g, 5);
         }
         function g() {}
-        console.log(6, typeof f, typeof g);
+        console.log(typeof f, typeof g, 6);
     }
     expect: {
         function g() {}
-        console.log(1, typeof f, typeof g);
-        if (console.log(2, typeof f, typeof g))
-            console.log(3, typeof f, typeof g);
+        console.log(typeof f, typeof g, 1);
+        if (console.log(typeof f, typeof g, 2))
+            console.log(typeof f, typeof g, 3);
         else {
-            console.log(4, typeof f, typeof g);
+            console.log(typeof f, typeof g, 4);
             function f() {}
-            console.log(5, typeof f, typeof g);
+            console.log(typeof f, typeof g, 5);
         }
-        console.log(6, typeof f, typeof g);
+        console.log(typeof f, typeof g, 6);
     }
     expect_stdout: [
-        "1 'undefined' 'function'",
-        "2 'undefined' 'function'",
-        "4 'function' 'function'",
-        "5 'function' 'function'",
-        "6 'function' 'function'",
+        "undefined function 1",
+        "undefined function 2",
+        "function function 4",
+        "function function 5",
+        "function function 6",
     ]
-    node_version: ">=6"
 }
 
 hoist_funs_strict: {
@@ -220,36 +219,36 @@ hoist_funs_strict: {
     }
     input: {
         "use strict";
-        console.log(1, typeof f, typeof g);
-        if (console.log(2, typeof f, typeof g))
-            console.log(3, typeof f, typeof g);
+        console.log(typeof f, typeof g, 1);
+        if (console.log(typeof f, typeof g, 2))
+            console.log(typeof f, typeof g, 3);
         else {
-            console.log(4, typeof f, typeof g);
+            console.log(typeof f, typeof g, 4);
             function f() {}
-            console.log(5, typeof f, typeof g);
+            console.log(typeof f, typeof g, 5);
         }
         function g() {}
-        console.log(6, typeof f, typeof g);
+        console.log(typeof f, typeof g, 6);
     }
     expect: {
         "use strict";
         function g() {}
-        console.log(1, typeof f, typeof g);
-        if (console.log(2, typeof f, typeof g))
-            console.log(3, typeof f, typeof g);
+        console.log(typeof f, typeof g, 1);
+        if (console.log(typeof f, typeof g, 2))
+            console.log(typeof f, typeof g, 3);
         else {
-            console.log(4, typeof f, typeof g);
+            console.log(typeof f, typeof g, 4);
             function f() {}
-            console.log(5, typeof f, typeof g);
+            console.log(typeof f, typeof g, 5);
         }
-        console.log(6, typeof f, typeof g);
+        console.log(typeof f, typeof g, 6);
     }
     expect_stdout: [
-        "1 'undefined' 'function'",
-        "2 'undefined' 'function'",
-        "4 'function' 'function'",
-        "5 'function' 'function'",
-        "6 'undefined' 'function'",
+        "undefined function 1",
+        "undefined function 2",
+        "function function 4",
+        "function function 5",
+        "undefined function 6",
     ]
 }
 
@@ -331,12 +330,11 @@ issue_2084: {
     }
     expect: {
         var c = 0;
-        !function(c) {
+        !function (c) {
             c = 1 + c,
-            c = 1 + (c = 0),
+                c = 1 + (c = 0),
             0 !== 23..toString() && (c = 1 + c);
-        }(-1),
-        console.log(c);
+        }(-1), console.log(c);
     }
     expect_stdout: "0"
 }
@@ -989,7 +987,7 @@ unsafe_apply_2: {
     expect_stdout: true
 }
 
-unsafe_apply_expansion: {
+unsafe_apply_expansion_1: {
     options = {
         unsafe: true,
     }
@@ -997,10 +995,24 @@ unsafe_apply_expansion: {
         console.log.apply(console, [1, ...[2, 3], 4]);
     }
     expect: {
-        console.log.call(console, 1, ...[2, 3], 4);
+        console.log.call(console, 1, 2, 3, 4);
+    }
+    expect_stdout: "1 2 3 4"
+}
+
+unsafe_apply_expansion_2: {
+    options = {
+        unsafe: true,
+    }
+    input: {
+        var values = [2, 3];
+        console.log.apply(console, [1, ...values, 4]);
+    }
+    expect: {
+        var values = [2, 3];
+        console.log.call(console, 1, ...values, 4);
     }
     expect_stdout: "1 2 3 4"
-    node_version: ">=6"
 }
 
 unsafe_call_1: {
@@ -1081,7 +1093,7 @@ unsafe_call_3: {
     expect_stdout: "3"
 }
 
-unsafe_call_expansion: {
+unsafe_call_expansion_1: {
     options = {
         unsafe: true,
     }
@@ -1094,10 +1106,29 @@ unsafe_call_expansion: {
         console,
         (function(...a) {
             console.log(...a);
-        })(1, ...[2, 3], 4);
+        })(1, 2, 3, 4);
+    }
+    expect_stdout: "1 2 3 4"
+}
+
+unsafe_call_expansion_2: {
+    options = {
+        unsafe: true,
+    }
+    input: {
+        var values = [2, 3];
+        (function(...a) {
+            console.log(...a);
+        }).call(console, 1, ...values, 4);
+    }
+    expect: {
+        var values = [2, 3];
+        console,
+        (function(...a) {
+            console.log(...a);
+        })(1, ...values, 4);
     }
     expect_stdout: "1 2 3 4"
-    node_version: ">=6"
 }
 
 issue_2616: {
@@ -1123,11 +1154,9 @@ issue_2616: {
     }
     expect: {
         var c = "FAIL";
-        (function() {
-            !function(NaN) {
-                (true << NaN) - 0/0 || (c = "PASS");
-            }([]);
-        })();
+        !function (NaN) {
+            (true << NaN) - 0 / 0 || (c = "PASS");
+        }([]);
         console.log(c);
     }
     expect_stdout: "PASS"
@@ -1158,14 +1187,11 @@ issue_2620_1: {
     }
     expect: {
         var c = "FAIL";
-        (function() {
-            (function(a) {
-                if (function(a) {
-                    a && a();
-                }(), a) c = "PASS";
-            })(1);
-        })(),
-        console.log(c);
+        !function (a) {
+            if (function (a) {
+                a && a();
+            }(), a) c = "PASS";
+        }(1), console.log(c);
     }
     expect_stdout: "PASS"
 }
@@ -1232,18 +1258,16 @@ issue_2620_3: {
     }
     expect: {
         var c = "FAIL";
-        (function() {
-            (function(a, NaN) {
-                (function() {
-                    switch (a) {
-                      case a:
+        !function (a, NaN) {
+            (function () {
+                switch (a) {
+                    case a:
                         break;
-                      case c = "PASS", NaN:
+                    case c = "PASS", NaN:
                         break;
-                    }
-                })();
-            })(NaN);
-        })();
+                }
+            })();
+        }(NaN);
         console.log(c);
     }
     expect_stdout: "PASS"
@@ -1495,7 +1519,6 @@ issue_2647_1: {
         "PASS",
         "PASS",
     ]
-    node_version: ">=6"
 }
 
 issue_2647_2: {
@@ -1542,9 +1565,7 @@ issue_2647_3: {
         }());
     }
     expect: {
-        (function() {
-            console.log("pass".toUpperCase());
-        })();
+        void console.log("pass".toUpperCase());
     }
     expect_stdout: "PASS"
 }
@@ -2591,7 +2612,6 @@ drop_lone_use_strict_arrows_1: {
             var f3 = () => {};
         };
     }
-    node_version: ">=6"
 }
 
 drop_lone_use_strict_arrows_2: {
@@ -2622,7 +2642,6 @@ drop_lone_use_strict_arrows_2: {
         let f1 = () => {};
         let f2 = () => {};
     }
-    node_version: ">=6"
 }
 
 issue_t131a: {
