@@ -621,7 +621,6 @@ issue_2028: {
         a.X().hello();
     }
     expect_stdout: "hello"
-    node_version: ">=6"
 }
 
 class_expression_statement: {
@@ -727,7 +726,7 @@ object_rest_spread: {
         (function({ y: o, ...l }) { console.log(l); })({ x: 1, y: 2, z: 3 });
         (({ y: o, ...l }) =>      { console.log(l); })({ x: 4, y: 5, z: 6 });
 
-        const w = { a: 1, b: 2 }; console.log({ ...w, w: 0, ...{}, ...n, ...{ K: 9 } });
+        const w = { a: 1, b: 2 }; console.log({ ...w, w: 0, ...n, K: 9 });
     }
 }
 
@@ -755,7 +754,7 @@ object_spread_unsafe: {
         console.log(cloned, merged);
     }
     expect: {
-        var o = { x: 1, y: 2 }, l = { ...o }, x = { ...o, ...{ x: 3, z: 4 } };
+        var o = { x: 1, y: 2 }, l = { ...o }, x = { ...o, x: 3, z: 4 };
         console.log(l, x);
     }
 }
@@ -784,7 +783,6 @@ array_spread_of_sequence: {
         "[ 1 ]",
         "[ 1 ]",
     ]
-    node_version: ">=6"
 }
 
 object_spread_of_sequence: {
@@ -855,7 +853,7 @@ issue_2345: {
         console.log([...a].join("-"));
     }
     expect: {
-        console.log([...[3, 2, 1]].join("-"));
+        console.log("3-2-1");
         var a = [3, 2, 1];
         console.log([...a].join("-"));
     }
@@ -863,7 +861,6 @@ issue_2345: {
         "3-2-1",
         "3-2-1",
     ]
-    node_version: ">=6"
 }
 
 issue_2349: {
@@ -990,10 +987,9 @@ array_literal_with_spread_1: {
         console.log(f([ "PASS" ]));
     }
     expect_stdout: "PASS"
-    node_version: ">=6"
 }
 
-array_literal_with_spread_2: {
+array_literal_with_spread_2a: {
     options = {
         properties: true,
         side_effects: true,
@@ -1008,13 +1004,13 @@ array_literal_with_spread_2: {
         console.log([10, ...[], 20, ...[30, 40], 50][5]);
     }
     expect: {
-        console.log([ 10, ...[], 20, ...[ 30, 40 ], 50 ]["length"]);
+        console.log([ 10, 20, 30, 40, 50 ]["length"]);
         console.log(10);
-        console.log([ 10, ...[], 20, ...[ 30, 40 ], 50 ][1]);
-        console.log([ 10, ...[], 20, ...[ 30, 40 ], 50 ][2]);
-        console.log([ 10, ...[], 20, ...[ 30, 40 ], 50 ][3]);
-        console.log([ 10, ...[], 20, ...[ 30, 40 ], 50 ][4]);
-        console.log([ 10, ...[], 20, ...[ 30, 40 ], 50 ][5]);
+        console.log(20);
+        console.log(30);
+        console.log(40);
+        console.log(50);
+        console.log([ 10, 20, 30, 40, 50 ][5]);
     }
     expect_stdout: [
         "5",
@@ -1025,10 +1021,45 @@ array_literal_with_spread_2: {
         "50",
         "undefined",
     ]
-    node_version: ">=6"
 }
 
-array_literal_with_spread_3: {
+array_literal_with_spread_2b: {
+    options = {
+        properties: true,
+        side_effects: true,
+    }
+    input: {
+        var x = [30, 40];
+        console.log([10, ...[], 20, ...x, 50]["length"]);
+        console.log([10, ...[], 20, ...x, 50][0]);
+        console.log([10, ...[], 20, ...x, 50][1]);
+        console.log([10, ...[], 20, ...x, 50][2]);
+        console.log([10, ...[], 20, ...x, 50][3]);
+        console.log([10, ...[], 20, ...x, 50][4]);
+        console.log([10, ...[], 20, ...x, 50][5]);
+    }
+    expect: {
+        var x = [30, 40];
+        console.log([ 10, 20, ...x, 50 ]["length"]);
+        console.log(10);
+        console.log(20);
+        console.log([ 10, 20, ...x, 50 ][2]);
+        console.log([ 10, 20, ...x, 50 ][3]);
+        console.log([ 10, 20, ...x, 50 ][4]);
+        console.log([ 10, 20, ...x, 50 ][5]);
+    }
+    expect_stdout: [
+        "5",
+        "10",
+        "20",
+        "30",
+        "40",
+        "50",
+        "undefined",
+    ]
+}
+
+array_literal_with_spread_3a: {
     options = {
         properties: true,
         side_effects: true,
@@ -1055,17 +1086,17 @@ array_literal_with_spread_3: {
         console.log(20);
         console.log([ 10, 20 ][2]);
 
-        console.log([...[], 10, 20][0]);
-        console.log([...[], 10, 20][1]);
-        console.log([...[], 10, 20][2]);
-
         console.log(10);
-        console.log([10, ...[], 20][1]);
-        console.log([10, ...[], 20][2]);
+        console.log(20);
+        console.log([10, 20][2]);
 
         console.log(10);
         console.log(20);
-        console.log([10, 20, ...[]][2]);
+        console.log([10, 20][2]);
+
+        console.log(10);
+        console.log(20);
+        console.log([10, 20][2]);
     }
     expect_stdout: [
         "10",
@@ -1081,10 +1112,66 @@ array_literal_with_spread_3: {
         "20",
         "undefined",
     ]
-    node_version: ">=6"
 }
 
-array_literal_with_spread_4: {
+array_literal_with_spread_3b: {
+    options = {
+        properties: true,
+        side_effects: true,
+    }
+    input: {
+        var nothing = [];
+        console.log([10, 20][0]);
+        console.log([10, 20][1]);
+        console.log([10, 20][2]);
+
+        console.log([...nothing, 10, 20][0]);
+        console.log([...nothing, 10, 20][1]);
+        console.log([...nothing, 10, 20][2]);
+
+        console.log([10, ...nothing, 20][0]);
+        console.log([10, ...nothing, 20][1]);
+        console.log([10, ...nothing, 20][2]);
+
+        console.log([10, 20, ...nothing][0]);
+        console.log([10, 20, ...nothing][1]);
+        console.log([10, 20, ...nothing][2]);
+    }
+    expect: {
+        var nothing = [];
+        console.log(10);
+        console.log(20);
+        console.log([ 10, 20 ][2]);
+
+        console.log([...nothing, 10, 20][0]);
+        console.log([...nothing, 10, 20][1]);
+        console.log([...nothing, 10, 20][2]);
+
+        console.log(10);
+        console.log([10, ...nothing, 20][1]);
+        console.log([10, ...nothing, 20][2]);
+
+        console.log(10);
+        console.log(20);
+        console.log([10, 20, ...nothing][2]);
+    }
+    expect_stdout: [
+        "10",
+        "20",
+        "undefined",
+        "10",
+        "20",
+        "undefined",
+        "10",
+        "20",
+        "undefined",
+        "10",
+        "20",
+        "undefined",
+    ]
+}
+
+array_literal_with_spread_4a: {
     options = {
         properties: true,
         side_effects: true,
@@ -1121,17 +1208,87 @@ array_literal_with_spread_4: {
         console.log((t(1), t(2)));
         console.log([ t(1), t(2) ][2]);
 
-        console.log([ ...[], t(1), t(2) ][0]);
-        console.log([ ...[], t(1), t(2) ][1]);
-        console.log([ ...[], t(1), t(2) ][2]);
-
         console.log([ t(1), t(2) ][0]);
-        console.log([ t(1), ...[], t(2) ][1]);
-        console.log([ t(1), ...[], t(2) ][2]);
+        console.log((t(1), t(2)));
+        console.log([ t(1), t(2) ][2]);
 
         console.log([ t(1), t(2) ][0]);
         console.log((t(1), t(2)));
-        console.log([ t(1), t(2), ...[] ][2]);
+        console.log([ t(1), t(2) ][2]);
+
+        console.log([ t(1), t(2) ][0]);
+        console.log((t(1), t(2)));
+        console.log([ t(1), t(2) ][2]);
+    }
+    expect_stdout: [
+        "(1)", "(2)", "10",
+        "(1)", "(2)", "20",
+        "(1)", "(2)", "undefined",
+
+        "(1)", "(2)", "10",
+        "(1)", "(2)", "20",
+        "(1)", "(2)", "undefined",
+
+        "(1)", "(2)", "10",
+        "(1)", "(2)", "20",
+        "(1)", "(2)", "undefined",
+
+        "(1)", "(2)", "10",
+        "(1)", "(2)", "20",
+        "(1)", "(2)", "undefined",
+    ]
+}
+
+array_literal_with_spread_4b: {
+    options = {
+        properties: true,
+        side_effects: true,
+    }
+    input: {
+        var nothing = [];
+        function t(x) {
+            console.log("(" + x + ")");
+            return 10 * x;
+        }
+
+        console.log([t(1), t(2)][0]);
+        console.log([t(1), t(2)][1]);
+        console.log([t(1), t(2)][2]);
+
+        console.log([...nothing, t(1), t(2)][0]);
+        console.log([...nothing, t(1), t(2)][1]);
+        console.log([...nothing, t(1), t(2)][2]);
+
+        console.log([t(1), ...nothing, t(2)][0]);
+        console.log([t(1), ...nothing, t(2)][1]);
+        console.log([t(1), ...nothing, t(2)][2]);
+
+        console.log([t(1), t(2), ...nothing][0]);
+        console.log([t(1), t(2), ...nothing][1]);
+        console.log([t(1), t(2), ...nothing][2]);
+    }
+    expect: {
+        var nothing = [];
+        function t(x) {
+            console.log("(" + x + ")");
+            return 10 * x;
+        }
+
+        console.log([ t(1), t(2) ][0]);
+        console.log((t(1), t(2)));
+        console.log([ t(1), t(2) ][2]);
+
+        console.log([ ...nothing, t(1), t(2) ][0]);
+        console.log([ ...nothing, t(1), t(2) ][1]);
+        console.log([ ...nothing, t(1), t(2) ][2]);
+
+        console.log([ t(1), t(2) ][0]);
+        console.log([ t(1), ...nothing, t(2) ][1]);
+        console.log([ t(1), ...nothing, t(2) ][2]);
+
+        console.log([ t(1), t(2) ][0]);
+        console.log((t(1), t(2)));
+        console.log([ t(1), t(2), ...nothing ][2]);
     }
     expect_stdout: [
         "(1)", "(2)", "10",
@@ -1150,7 +1307,6 @@ array_literal_with_spread_4: {
         "(1)", "(2)", "20",
         "(1)", "(2)", "undefined",
     ]
-    node_version: ">=6"
 }
 
 object_literal_method_using_arguments: {
@@ -1172,7 +1328,6 @@ object_literal_method_using_arguments: {
         }).m("PASS"));
     }
     expect_stdout: "PASS"
-    node_version: ">=6"
 }
 
 class_method_using_arguments: {
@@ -1194,7 +1349,6 @@ class_method_using_arguments: {
         }().m("PASS"));
     }
     expect_stdout: "PASS"
-    node_version: ">=6"
 }
 
 issue_2676: {
@@ -1288,7 +1442,6 @@ issue_2794_1: {
         "20",
         "30",
     ]
-    node_version: ">=6"
 }
 
 issue_2794_2: {
@@ -1337,7 +1490,6 @@ issue_2794_2: {
         "20",
         "30",
     ]
-    node_version: ">=6"
 }
 
 issue_2794_3: {
@@ -1381,7 +1533,6 @@ issue_2794_3: {
         "20",
         "30",
     ]
-    node_version: ">=6"
 }
 
 issue_2794_4: {
@@ -1396,7 +1547,6 @@ issue_2794_4: {
         "3",
         "4",
     ]
-    node_version: ">=6"
 }
 
 issue_2794_5: {
@@ -1417,7 +1567,6 @@ issue_2794_5: {
         "3",
         "4",
     ]
-    node_version: ">=6"
 }
 
 issue_2794_6: {
@@ -1436,7 +1585,6 @@ issue_2794_6: {
         "4",
         "5",
     ]
-    node_version: ">=6"
 }
 
 inline_arrow_using_arguments: {
@@ -1467,7 +1615,6 @@ inline_arrow_using_arguments: {
         "3 2 1",
         "4",
     ]
-    node_version: ">=6"
 }
 
 issue_2874_1: {
@@ -1495,21 +1642,18 @@ issue_2874_1: {
         })();
     }
     expect: {
-        (function() {
-            (function() {
-                let letters = [ "A", "B", "C" ];
-                return [ 2, 1, 0 ].map(key => (function(value) {
-                    return () => console.log(value);
-                })(letters[key] + key));
-            })().map(fn => fn());
-        })();
+        (function () {
+            let letters = ["A", "B", "C"];
+            return [2, 1, 0].map(key => (function (value) {
+                return () => console.log(value);
+            })(letters[key] + key));
+        })().map(fn => fn());
     }
     expect_stdout: [
         "C2",
         "B1",
         "A0",
     ]
-    node_version: ">=6"
 }
 
 issue_2874_2: {
@@ -1556,7 +1700,6 @@ issue_2874_2: {
         "B1",
         "A0",
     ]
-    node_version: ">=6"
 }
 
 issue_2874_3: {
@@ -1598,7 +1741,6 @@ issue_2874_3: {
         "A1",
         "A2",
     ]
-    node_version: ">=6"
 }
 
 issue_3061: {
@@ -1622,7 +1764,6 @@ issue_3061: {
         }(Error)){}() instanceof Error);
     }
     expect_stdout: "true"
-    node_version: ">=6"
 }
 
 module_enables_strict_mode: {
@@ -1696,7 +1837,6 @@ issue_3028: {
         console.log(a([ 1, 2, 3 ]).join(" "));
     }
     expect_stdout: "3 1 2"
-    node_version: ">=6"
 }
 
 issue_t80: {
@@ -1722,5 +1862,4 @@ issue_t80: {
         console.log(JSON.stringify([foo(), foo(null), foo(5, 6)]));
     }
     expect_stdout: "[[],[null],5]"
-    node_version: ">=6"
 }
