@@ -4,7 +4,7 @@ try {
     require("source-map-support").install();
 } catch (err) {}
 
-var U = process.env.TERSER_NO_BUNDLE ? require("./node") : require("../dist/bundle");
+var U = require("../dist/bundle.js");
 var path = require("path");
 var fs = require("fs");
 var assert = require("assert");
@@ -67,7 +67,7 @@ function find_test_files(dir) {
     if (process.argv.length > 2) {
         var x = process.argv.slice(2);
         files = files.filter(function(f){
-            return x.indexOf(f) >= 0;
+            return x.includes(f);
         });
     }
     return files;
@@ -202,7 +202,9 @@ function run_compress_tests() {
                 var quoted_props = test.mangle.properties.reserved;
                 if (!Array.isArray(quoted_props)) quoted_props = [];
                 test.mangle.properties.reserved = quoted_props;
-                U.reserve_quoted_keys(input, quoted_props);
+                if (test.mangle.properties.keep_quoted !== "strict") {
+                    U.reserve_quoted_keys(input, quoted_props);
+                }
             }
             if (test.rename) {
                 input.figure_out_scope(test.mangle);
@@ -217,9 +219,15 @@ function run_compress_tests() {
                 (function(cache) {
                     if (!cache) return;
                     if (!("props" in cache)) {
-                        cache.props = new U.Dictionary();
-                    } else if (!(cache.props instanceof U.Dictionary)) {
-                        cache.props = U.Dictionary.fromObject(cache.props);
+                        cache.props = new Map();
+                    } else if (!(cache.props instanceof Map)) {
+                        const props = new Map();
+                        for (const key in cache.props) {
+                            if (HOP(cache.props, key) && key.charAt(0) === '$') {
+                                props.set(key.substr(1), cache.props[key]);
+                            }
+                        }
+                        cache.props = props;
                     }
                 })(test.mangle.cache);
                 output.mangle_names(test.mangle);
@@ -406,7 +414,7 @@ function parse_test(file) {
                         "expect_stdout",
                         "node_version",
                         "reminify",
-                    ].indexOf(label.name) >= 0,
+                    ].includes(label.name),
                     tmpl("Unsupported label {name} [{line},{col}]", {
                         name: label.name,
                         line: label.start.line,
